# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetGlobalDatabaseNetworksResult',
    'AwaitableGetGlobalDatabaseNetworksResult',
    'get_global_database_networks',
    'get_global_database_networks_output',
]

@pulumi.output_type
class GetGlobalDatabaseNetworksResult:
    """
    A collection of values returned by getGlobalDatabaseNetworks.
    """
    def __init__(__self__, db_cluster_id=None, description=None, gdn_id=None, id=None, ids=None, networks=None, output_file=None, page_number=None, page_size=None, status=None):
        if db_cluster_id and not isinstance(db_cluster_id, str):
            raise TypeError("Expected argument 'db_cluster_id' to be a str")
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if gdn_id and not isinstance(gdn_id, str):
            raise TypeError("Expected argument 'gdn_id' to be a str")
        pulumi.set(__self__, "gdn_id", gdn_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if networks and not isinstance(networks, list):
            raise TypeError("Expected argument 'networks' to be a list")
        pulumi.set(__self__, "networks", networks)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> Optional[str]:
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="gdnId")
    def gdn_id(self) -> Optional[str]:
        return pulumi.get(self, "gdn_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def networks(self) -> Sequence['outputs.GetGlobalDatabaseNetworksNetworkResult']:
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetGlobalDatabaseNetworksResult(GetGlobalDatabaseNetworksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGlobalDatabaseNetworksResult(
            db_cluster_id=self.db_cluster_id,
            description=self.description,
            gdn_id=self.gdn_id,
            id=self.id,
            ids=self.ids,
            networks=self.networks,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            status=self.status)


def get_global_database_networks(db_cluster_id: Optional[str] = None,
                                 description: Optional[str] = None,
                                 gdn_id: Optional[str] = None,
                                 ids: Optional[Sequence[str]] = None,
                                 output_file: Optional[str] = None,
                                 page_number: Optional[int] = None,
                                 page_size: Optional[int] = None,
                                 status: Optional[str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGlobalDatabaseNetworksResult:
    """
    This data source provides the PolarDB Global Database Networks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.181.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.polardb.get_global_database_networks(ids=["example_id"])
    pulumi.export("polardbGlobalDatabaseNetworkId1", ids.networks[0].id)
    description = alicloud.polardb.get_global_database_networks(description="example_description")
    pulumi.export("polardbGlobalDatabaseNetworkId2", description.networks[0].id)
    ```


    :param str db_cluster_id: The ID of the PolarDB cluster.
    :param str description: The description of the Global Database Network.
    :param str gdn_id: The ID of the Global Database Network.
    :param Sequence[str] ids: A list of Global Database Network IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Database Network.
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['description'] = description
    __args__['gdnId'] = gdn_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:polardb/getGlobalDatabaseNetworks:getGlobalDatabaseNetworks', __args__, opts=opts, typ=GetGlobalDatabaseNetworksResult).value

    return AwaitableGetGlobalDatabaseNetworksResult(
        db_cluster_id=pulumi.get(__ret__, 'db_cluster_id'),
        description=pulumi.get(__ret__, 'description'),
        gdn_id=pulumi.get(__ret__, 'gdn_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        networks=pulumi.get(__ret__, 'networks'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        status=pulumi.get(__ret__, 'status'))


@_utilities.lift_output_func(get_global_database_networks)
def get_global_database_networks_output(db_cluster_id: Optional[pulumi.Input[Optional[str]]] = None,
                                        description: Optional[pulumi.Input[Optional[str]]] = None,
                                        gdn_id: Optional[pulumi.Input[Optional[str]]] = None,
                                        ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                        output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                        page_number: Optional[pulumi.Input[Optional[int]]] = None,
                                        page_size: Optional[pulumi.Input[Optional[int]]] = None,
                                        status: Optional[pulumi.Input[Optional[str]]] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGlobalDatabaseNetworksResult]:
    """
    This data source provides the PolarDB Global Database Networks of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.181.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.polardb.get_global_database_networks(ids=["example_id"])
    pulumi.export("polardbGlobalDatabaseNetworkId1", ids.networks[0].id)
    description = alicloud.polardb.get_global_database_networks(description="example_description")
    pulumi.export("polardbGlobalDatabaseNetworkId2", description.networks[0].id)
    ```


    :param str db_cluster_id: The ID of the PolarDB cluster.
    :param str description: The description of the Global Database Network.
    :param str gdn_id: The ID of the Global Database Network.
    :param Sequence[str] ids: A list of Global Database Network IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Database Network.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetBasicAccelerateIpsResult',
    'AwaitableGetBasicAccelerateIpsResult',
    'get_basic_accelerate_ips',
    'get_basic_accelerate_ips_output',
]

@pulumi.output_type
class GetBasicAccelerateIpsResult:
    """
    A collection of values returned by getBasicAccelerateIps.
    """
    def __init__(__self__, accelerate_ip_address=None, accelerate_ip_id=None, id=None, ids=None, ip_set_id=None, ips=None, output_file=None, status=None):
        if accelerate_ip_address and not isinstance(accelerate_ip_address, str):
            raise TypeError("Expected argument 'accelerate_ip_address' to be a str")
        pulumi.set(__self__, "accelerate_ip_address", accelerate_ip_address)
        if accelerate_ip_id and not isinstance(accelerate_ip_id, str):
            raise TypeError("Expected argument 'accelerate_ip_id' to be a str")
        pulumi.set(__self__, "accelerate_ip_id", accelerate_ip_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if ip_set_id and not isinstance(ip_set_id, str):
            raise TypeError("Expected argument 'ip_set_id' to be a str")
        pulumi.set(__self__, "ip_set_id", ip_set_id)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accelerateIpAddress")
    def accelerate_ip_address(self) -> Optional[str]:
        """
        The address of the Basic Accelerate IP.
        """
        return pulumi.get(self, "accelerate_ip_address")

    @property
    @pulumi.getter(name="accelerateIpId")
    def accelerate_ip_id(self) -> Optional[str]:
        """
        The id of the Basic Accelerate IP.
        """
        return pulumi.get(self, "accelerate_ip_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="ipSetId")
    def ip_set_id(self) -> str:
        """
        The ID of the Basic Ip Set.
        """
        return pulumi.get(self, "ip_set_id")

    @property
    @pulumi.getter
    def ips(self) -> Sequence['outputs.GetBasicAccelerateIpsIpResult']:
        """
        A list of Global Accelerator Basic Accelerate IPs. Each element contains the following attributes:
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the Basic Accelerate IP instance.
        """
        return pulumi.get(self, "status")


class AwaitableGetBasicAccelerateIpsResult(GetBasicAccelerateIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBasicAccelerateIpsResult(
            accelerate_ip_address=self.accelerate_ip_address,
            accelerate_ip_id=self.accelerate_ip_id,
            id=self.id,
            ids=self.ids,
            ip_set_id=self.ip_set_id,
            ips=self.ips,
            output_file=self.output_file,
            status=self.status)


def get_basic_accelerate_ips(accelerate_ip_address: Optional[str] = None,
                             accelerate_ip_id: Optional[str] = None,
                             ids: Optional[Sequence[str]] = None,
                             ip_set_id: Optional[str] = None,
                             output_file: Optional[str] = None,
                             status: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBasicAccelerateIpsResult:
    """
    This data source provides the Global Accelerator (GA) Basic Accelerate IPs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_accelerate_ips(ids=["example_id"],
        ip_set_id="example_ip_set_id")
    pulumi.export("gaBasicAccelerateIpId1", ids.ips[0].id)
    ```


    :param str accelerate_ip_address: The address of the Basic Accelerate IP.
    :param str accelerate_ip_id: The id of the Basic Accelerate IP.
    :param Sequence[str] ids: A list of Global Accelerator Basic Accelerate IP IDs.
    :param str ip_set_id: The ID of the Basic Ip Set.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Accelerator Basic Accelerate IP instance. Valid Value: `active`, `binding`, `bound`, `unbinding`, `deleting`.
    """
    __args__ = dict()
    __args__['accelerateIpAddress'] = accelerate_ip_address
    __args__['accelerateIpId'] = accelerate_ip_id
    __args__['ids'] = ids
    __args__['ipSetId'] = ip_set_id
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getBasicAccelerateIps:getBasicAccelerateIps', __args__, opts=opts, typ=GetBasicAccelerateIpsResult).value

    return AwaitableGetBasicAccelerateIpsResult(
        accelerate_ip_address=pulumi.get(__ret__, 'accelerate_ip_address'),
        accelerate_ip_id=pulumi.get(__ret__, 'accelerate_ip_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        ip_set_id=pulumi.get(__ret__, 'ip_set_id'),
        ips=pulumi.get(__ret__, 'ips'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))


@_utilities.lift_output_func(get_basic_accelerate_ips)
def get_basic_accelerate_ips_output(accelerate_ip_address: Optional[pulumi.Input[Optional[str]]] = None,
                                    accelerate_ip_id: Optional[pulumi.Input[Optional[str]]] = None,
                                    ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                    ip_set_id: Optional[pulumi.Input[str]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    status: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBasicAccelerateIpsResult]:
    """
    This data source provides the Global Accelerator (GA) Basic Accelerate IPs of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_accelerate_ips(ids=["example_id"],
        ip_set_id="example_ip_set_id")
    pulumi.export("gaBasicAccelerateIpId1", ids.ips[0].id)
    ```


    :param str accelerate_ip_address: The address of the Basic Accelerate IP.
    :param str accelerate_ip_id: The id of the Basic Accelerate IP.
    :param Sequence[str] ids: A list of Global Accelerator Basic Accelerate IP IDs.
    :param str ip_set_id: The ID of the Basic Ip Set.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Accelerator Basic Accelerate IP instance. Valid Value: `active`, `binding`, `bound`, `unbinding`, `deleting`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 big_screen: pulumi.Input[str],
                 exclusive_ip_package: pulumi.Input[str],
                 ext_bandwidth: pulumi.Input[str],
                 ext_domain_package: pulumi.Input[str],
                 log_storage: pulumi.Input[str],
                 log_time: pulumi.Input[str],
                 package_code: pulumi.Input[str],
                 prefessional_service: pulumi.Input[str],
                 subscription_type: pulumi.Input[str],
                 waf_log: pulumi.Input[str],
                 modify_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] big_screen: Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        :param pulumi.Input[str] exclusive_ip_package: Specify the number of exclusive WAF IP addresses.
        :param pulumi.Input[str] ext_bandwidth: The extra bandwidth. Unit: Mbit/s.
        :param pulumi.Input[str] ext_domain_package: The number of extra domains.
        :param pulumi.Input[str] log_storage: Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        :param pulumi.Input[str] log_time: Log storage period. Unit: day. Valid values: [180, 360].
        :param pulumi.Input[str] package_code: Subscription plan:
               * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
               * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
               * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
               * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        :param pulumi.Input[str] prefessional_service: Specify whether professional service is supported. Valid values: ["true", "false"]
        :param pulumi.Input[str] subscription_type: Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        :param pulumi.Input[str] waf_log: Specify whether Log service is supported. Valid values: ["true", "false"]
        :param pulumi.Input[str] modify_type: Type of configuration change. Valid value: Upgrade.
        :param pulumi.Input[int] period: Service time of Web Application Firewall.
        :param pulumi.Input[str] region: The instance region ID.
        :param pulumi.Input[int] renew_period: Renewal period of WAF service. Unit: month
        :param pulumi.Input[str] renewal_status: Renewal status of WAF service. Valid values: 
               * AutoRenewal: The service time of WAF is renewed automatically.
               * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        """
        pulumi.set(__self__, "big_screen", big_screen)
        pulumi.set(__self__, "exclusive_ip_package", exclusive_ip_package)
        pulumi.set(__self__, "ext_bandwidth", ext_bandwidth)
        pulumi.set(__self__, "ext_domain_package", ext_domain_package)
        pulumi.set(__self__, "log_storage", log_storage)
        pulumi.set(__self__, "log_time", log_time)
        pulumi.set(__self__, "package_code", package_code)
        pulumi.set(__self__, "prefessional_service", prefessional_service)
        pulumi.set(__self__, "subscription_type", subscription_type)
        pulumi.set(__self__, "waf_log", waf_log)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)

    @property
    @pulumi.getter(name="bigScreen")
    def big_screen(self) -> pulumi.Input[str]:
        """
        Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        """
        return pulumi.get(self, "big_screen")

    @big_screen.setter
    def big_screen(self, value: pulumi.Input[str]):
        pulumi.set(self, "big_screen", value)

    @property
    @pulumi.getter(name="exclusiveIpPackage")
    def exclusive_ip_package(self) -> pulumi.Input[str]:
        """
        Specify the number of exclusive WAF IP addresses.
        """
        return pulumi.get(self, "exclusive_ip_package")

    @exclusive_ip_package.setter
    def exclusive_ip_package(self, value: pulumi.Input[str]):
        pulumi.set(self, "exclusive_ip_package", value)

    @property
    @pulumi.getter(name="extBandwidth")
    def ext_bandwidth(self) -> pulumi.Input[str]:
        """
        The extra bandwidth. Unit: Mbit/s.
        """
        return pulumi.get(self, "ext_bandwidth")

    @ext_bandwidth.setter
    def ext_bandwidth(self, value: pulumi.Input[str]):
        pulumi.set(self, "ext_bandwidth", value)

    @property
    @pulumi.getter(name="extDomainPackage")
    def ext_domain_package(self) -> pulumi.Input[str]:
        """
        The number of extra domains.
        """
        return pulumi.get(self, "ext_domain_package")

    @ext_domain_package.setter
    def ext_domain_package(self, value: pulumi.Input[str]):
        pulumi.set(self, "ext_domain_package", value)

    @property
    @pulumi.getter(name="logStorage")
    def log_storage(self) -> pulumi.Input[str]:
        """
        Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        """
        return pulumi.get(self, "log_storage")

    @log_storage.setter
    def log_storage(self, value: pulumi.Input[str]):
        pulumi.set(self, "log_storage", value)

    @property
    @pulumi.getter(name="logTime")
    def log_time(self) -> pulumi.Input[str]:
        """
        Log storage period. Unit: day. Valid values: [180, 360].
        """
        return pulumi.get(self, "log_time")

    @log_time.setter
    def log_time(self, value: pulumi.Input[str]):
        pulumi.set(self, "log_time", value)

    @property
    @pulumi.getter(name="packageCode")
    def package_code(self) -> pulumi.Input[str]:
        """
        Subscription plan:
        * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
        * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
        * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
        * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        """
        return pulumi.get(self, "package_code")

    @package_code.setter
    def package_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "package_code", value)

    @property
    @pulumi.getter(name="prefessionalService")
    def prefessional_service(self) -> pulumi.Input[str]:
        """
        Specify whether professional service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "prefessional_service")

    @prefessional_service.setter
    def prefessional_service(self, value: pulumi.Input[str]):
        pulumi.set(self, "prefessional_service", value)

    @property
    @pulumi.getter(name="subscriptionType")
    def subscription_type(self) -> pulumi.Input[str]:
        """
        Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        """
        return pulumi.get(self, "subscription_type")

    @subscription_type.setter
    def subscription_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "subscription_type", value)

    @property
    @pulumi.getter(name="wafLog")
    def waf_log(self) -> pulumi.Input[str]:
        """
        Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "waf_log")

    @waf_log.setter
    def waf_log(self, value: pulumi.Input[str]):
        pulumi.set(self, "waf_log", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of configuration change. Valid value: Upgrade.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Service time of Web Application Firewall.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The instance region ID.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Renewal period of WAF service. Unit: month
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Renewal status of WAF service. Valid values: 
        * AutoRenewal: The service time of WAF is renewed automatically.
        * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 big_screen: Optional[pulumi.Input[str]] = None,
                 exclusive_ip_package: Optional[pulumi.Input[str]] = None,
                 ext_bandwidth: Optional[pulumi.Input[str]] = None,
                 ext_domain_package: Optional[pulumi.Input[str]] = None,
                 log_storage: Optional[pulumi.Input[str]] = None,
                 log_time: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 package_code: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 prefessional_service: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 subscription_type: Optional[pulumi.Input[str]] = None,
                 waf_log: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[str] big_screen: Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        :param pulumi.Input[str] exclusive_ip_package: Specify the number of exclusive WAF IP addresses.
        :param pulumi.Input[str] ext_bandwidth: The extra bandwidth. Unit: Mbit/s.
        :param pulumi.Input[str] ext_domain_package: The number of extra domains.
        :param pulumi.Input[str] log_storage: Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        :param pulumi.Input[str] log_time: Log storage period. Unit: day. Valid values: [180, 360].
        :param pulumi.Input[str] modify_type: Type of configuration change. Valid value: Upgrade.
        :param pulumi.Input[str] package_code: Subscription plan:
               * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
               * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
               * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
               * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        :param pulumi.Input[int] period: Service time of Web Application Firewall.
        :param pulumi.Input[str] prefessional_service: Specify whether professional service is supported. Valid values: ["true", "false"]
        :param pulumi.Input[str] region: The instance region ID.
        :param pulumi.Input[int] renew_period: Renewal period of WAF service. Unit: month
        :param pulumi.Input[str] renewal_status: Renewal status of WAF service. Valid values: 
               * AutoRenewal: The service time of WAF is renewed automatically.
               * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[int] status: The status of the instance.
        :param pulumi.Input[str] subscription_type: Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        :param pulumi.Input[str] waf_log: Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        if big_screen is not None:
            pulumi.set(__self__, "big_screen", big_screen)
        if exclusive_ip_package is not None:
            pulumi.set(__self__, "exclusive_ip_package", exclusive_ip_package)
        if ext_bandwidth is not None:
            pulumi.set(__self__, "ext_bandwidth", ext_bandwidth)
        if ext_domain_package is not None:
            pulumi.set(__self__, "ext_domain_package", ext_domain_package)
        if log_storage is not None:
            pulumi.set(__self__, "log_storage", log_storage)
        if log_time is not None:
            pulumi.set(__self__, "log_time", log_time)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if package_code is not None:
            pulumi.set(__self__, "package_code", package_code)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if prefessional_service is not None:
            pulumi.set(__self__, "prefessional_service", prefessional_service)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subscription_type is not None:
            pulumi.set(__self__, "subscription_type", subscription_type)
        if waf_log is not None:
            pulumi.set(__self__, "waf_log", waf_log)

    @property
    @pulumi.getter(name="bigScreen")
    def big_screen(self) -> Optional[pulumi.Input[str]]:
        """
        Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        """
        return pulumi.get(self, "big_screen")

    @big_screen.setter
    def big_screen(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "big_screen", value)

    @property
    @pulumi.getter(name="exclusiveIpPackage")
    def exclusive_ip_package(self) -> Optional[pulumi.Input[str]]:
        """
        Specify the number of exclusive WAF IP addresses.
        """
        return pulumi.get(self, "exclusive_ip_package")

    @exclusive_ip_package.setter
    def exclusive_ip_package(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclusive_ip_package", value)

    @property
    @pulumi.getter(name="extBandwidth")
    def ext_bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The extra bandwidth. Unit: Mbit/s.
        """
        return pulumi.get(self, "ext_bandwidth")

    @ext_bandwidth.setter
    def ext_bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ext_bandwidth", value)

    @property
    @pulumi.getter(name="extDomainPackage")
    def ext_domain_package(self) -> Optional[pulumi.Input[str]]:
        """
        The number of extra domains.
        """
        return pulumi.get(self, "ext_domain_package")

    @ext_domain_package.setter
    def ext_domain_package(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ext_domain_package", value)

    @property
    @pulumi.getter(name="logStorage")
    def log_storage(self) -> Optional[pulumi.Input[str]]:
        """
        Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        """
        return pulumi.get(self, "log_storage")

    @log_storage.setter
    def log_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_storage", value)

    @property
    @pulumi.getter(name="logTime")
    def log_time(self) -> Optional[pulumi.Input[str]]:
        """
        Log storage period. Unit: day. Valid values: [180, 360].
        """
        return pulumi.get(self, "log_time")

    @log_time.setter
    def log_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_time", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of configuration change. Valid value: Upgrade.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter(name="packageCode")
    def package_code(self) -> Optional[pulumi.Input[str]]:
        """
        Subscription plan:
        * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
        * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
        * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
        * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        """
        return pulumi.get(self, "package_code")

    @package_code.setter
    def package_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_code", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Service time of Web Application Firewall.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="prefessionalService")
    def prefessional_service(self) -> Optional[pulumi.Input[str]]:
        """
        Specify whether professional service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "prefessional_service")

    @prefessional_service.setter
    def prefessional_service(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefessional_service", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The instance region ID.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Renewal period of WAF service. Unit: month
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Renewal status of WAF service. Valid values: 
        * AutoRenewal: The service time of WAF is renewed automatically.
        * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        The status of the instance.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subscriptionType")
    def subscription_type(self) -> Optional[pulumi.Input[str]]:
        """
        Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        """
        return pulumi.get(self, "subscription_type")

    @subscription_type.setter
    def subscription_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subscription_type", value)

    @property
    @pulumi.getter(name="wafLog")
    def waf_log(self) -> Optional[pulumi.Input[str]]:
        """
        Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "waf_log")

    @waf_log.setter
    def waf_log(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_log", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 big_screen: Optional[pulumi.Input[str]] = None,
                 exclusive_ip_package: Optional[pulumi.Input[str]] = None,
                 ext_bandwidth: Optional[pulumi.Input[str]] = None,
                 ext_domain_package: Optional[pulumi.Input[str]] = None,
                 log_storage: Optional[pulumi.Input[str]] = None,
                 log_time: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 package_code: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 prefessional_service: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 subscription_type: Optional[pulumi.Input[str]] = None,
                 waf_log: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a WAF Instance resource to create instance in the Web Application Firewall.

        For information about WAF and how to use it, see [What is Alibaba Cloud WAF](https://www.alibabacloud.com/help/doc-detail/28517.htm).

        > **NOTE:** Available in 1.83.0+ .

        ## Import

        WAF instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:waf/instance:Instance default waf-cn-132435
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] big_screen: Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        :param pulumi.Input[str] exclusive_ip_package: Specify the number of exclusive WAF IP addresses.
        :param pulumi.Input[str] ext_bandwidth: The extra bandwidth. Unit: Mbit/s.
        :param pulumi.Input[str] ext_domain_package: The number of extra domains.
        :param pulumi.Input[str] log_storage: Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        :param pulumi.Input[str] log_time: Log storage period. Unit: day. Valid values: [180, 360].
        :param pulumi.Input[str] modify_type: Type of configuration change. Valid value: Upgrade.
        :param pulumi.Input[str] package_code: Subscription plan:
               * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
               * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
               * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
               * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        :param pulumi.Input[int] period: Service time of Web Application Firewall.
        :param pulumi.Input[str] prefessional_service: Specify whether professional service is supported. Valid values: ["true", "false"]
        :param pulumi.Input[str] region: The instance region ID.
        :param pulumi.Input[int] renew_period: Renewal period of WAF service. Unit: month
        :param pulumi.Input[str] renewal_status: Renewal status of WAF service. Valid values: 
               * AutoRenewal: The service time of WAF is renewed automatically.
               * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[str] subscription_type: Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        :param pulumi.Input[str] waf_log: Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a WAF Instance resource to create instance in the Web Application Firewall.

        For information about WAF and how to use it, see [What is Alibaba Cloud WAF](https://www.alibabacloud.com/help/doc-detail/28517.htm).

        > **NOTE:** Available in 1.83.0+ .

        ## Import

        WAF instance can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:waf/instance:Instance default waf-cn-132435
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 big_screen: Optional[pulumi.Input[str]] = None,
                 exclusive_ip_package: Optional[pulumi.Input[str]] = None,
                 ext_bandwidth: Optional[pulumi.Input[str]] = None,
                 ext_domain_package: Optional[pulumi.Input[str]] = None,
                 log_storage: Optional[pulumi.Input[str]] = None,
                 log_time: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 package_code: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 prefessional_service: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 subscription_type: Optional[pulumi.Input[str]] = None,
                 waf_log: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            if big_screen is None and not opts.urn:
                raise TypeError("Missing required property 'big_screen'")
            __props__.__dict__["big_screen"] = big_screen
            if exclusive_ip_package is None and not opts.urn:
                raise TypeError("Missing required property 'exclusive_ip_package'")
            __props__.__dict__["exclusive_ip_package"] = exclusive_ip_package
            if ext_bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'ext_bandwidth'")
            __props__.__dict__["ext_bandwidth"] = ext_bandwidth
            if ext_domain_package is None and not opts.urn:
                raise TypeError("Missing required property 'ext_domain_package'")
            __props__.__dict__["ext_domain_package"] = ext_domain_package
            if log_storage is None and not opts.urn:
                raise TypeError("Missing required property 'log_storage'")
            __props__.__dict__["log_storage"] = log_storage
            if log_time is None and not opts.urn:
                raise TypeError("Missing required property 'log_time'")
            __props__.__dict__["log_time"] = log_time
            __props__.__dict__["modify_type"] = modify_type
            if package_code is None and not opts.urn:
                raise TypeError("Missing required property 'package_code'")
            __props__.__dict__["package_code"] = package_code
            __props__.__dict__["period"] = period
            if prefessional_service is None and not opts.urn:
                raise TypeError("Missing required property 'prefessional_service'")
            __props__.__dict__["prefessional_service"] = prefessional_service
            __props__.__dict__["region"] = region
            __props__.__dict__["renew_period"] = renew_period
            __props__.__dict__["renewal_status"] = renewal_status
            __props__.__dict__["resource_group_id"] = resource_group_id
            if subscription_type is None and not opts.urn:
                raise TypeError("Missing required property 'subscription_type'")
            __props__.__dict__["subscription_type"] = subscription_type
            if waf_log is None and not opts.urn:
                raise TypeError("Missing required property 'waf_log'")
            __props__.__dict__["waf_log"] = waf_log
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:waf/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            big_screen: Optional[pulumi.Input[str]] = None,
            exclusive_ip_package: Optional[pulumi.Input[str]] = None,
            ext_bandwidth: Optional[pulumi.Input[str]] = None,
            ext_domain_package: Optional[pulumi.Input[str]] = None,
            log_storage: Optional[pulumi.Input[str]] = None,
            log_time: Optional[pulumi.Input[str]] = None,
            modify_type: Optional[pulumi.Input[str]] = None,
            package_code: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            prefessional_service: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            renew_period: Optional[pulumi.Input[int]] = None,
            renewal_status: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[int]] = None,
            subscription_type: Optional[pulumi.Input[str]] = None,
            waf_log: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] big_screen: Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        :param pulumi.Input[str] exclusive_ip_package: Specify the number of exclusive WAF IP addresses.
        :param pulumi.Input[str] ext_bandwidth: The extra bandwidth. Unit: Mbit/s.
        :param pulumi.Input[str] ext_domain_package: The number of extra domains.
        :param pulumi.Input[str] log_storage: Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        :param pulumi.Input[str] log_time: Log storage period. Unit: day. Valid values: [180, 360].
        :param pulumi.Input[str] modify_type: Type of configuration change. Valid value: Upgrade.
        :param pulumi.Input[str] package_code: Subscription plan:
               * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
               * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
               * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
               * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        :param pulumi.Input[int] period: Service time of Web Application Firewall.
        :param pulumi.Input[str] prefessional_service: Specify whether professional service is supported. Valid values: ["true", "false"]
        :param pulumi.Input[str] region: The instance region ID.
        :param pulumi.Input[int] renew_period: Renewal period of WAF service. Unit: month
        :param pulumi.Input[str] renewal_status: Renewal status of WAF service. Valid values: 
               * AutoRenewal: The service time of WAF is renewed automatically.
               * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        :param pulumi.Input[str] resource_group_id: The resource group ID.
        :param pulumi.Input[int] status: The status of the instance.
        :param pulumi.Input[str] subscription_type: Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        :param pulumi.Input[str] waf_log: Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["big_screen"] = big_screen
        __props__.__dict__["exclusive_ip_package"] = exclusive_ip_package
        __props__.__dict__["ext_bandwidth"] = ext_bandwidth
        __props__.__dict__["ext_domain_package"] = ext_domain_package
        __props__.__dict__["log_storage"] = log_storage
        __props__.__dict__["log_time"] = log_time
        __props__.__dict__["modify_type"] = modify_type
        __props__.__dict__["package_code"] = package_code
        __props__.__dict__["period"] = period
        __props__.__dict__["prefessional_service"] = prefessional_service
        __props__.__dict__["region"] = region
        __props__.__dict__["renew_period"] = renew_period
        __props__.__dict__["renewal_status"] = renewal_status
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["subscription_type"] = subscription_type
        __props__.__dict__["waf_log"] = waf_log
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bigScreen")
    def big_screen(self) -> pulumi.Output[str]:
        """
        Specify whether big screen is supported. Valid values: ["0", "1"]. "0" for false and "1" for true.
        """
        return pulumi.get(self, "big_screen")

    @property
    @pulumi.getter(name="exclusiveIpPackage")
    def exclusive_ip_package(self) -> pulumi.Output[str]:
        """
        Specify the number of exclusive WAF IP addresses.
        """
        return pulumi.get(self, "exclusive_ip_package")

    @property
    @pulumi.getter(name="extBandwidth")
    def ext_bandwidth(self) -> pulumi.Output[str]:
        """
        The extra bandwidth. Unit: Mbit/s.
        """
        return pulumi.get(self, "ext_bandwidth")

    @property
    @pulumi.getter(name="extDomainPackage")
    def ext_domain_package(self) -> pulumi.Output[str]:
        """
        The number of extra domains.
        """
        return pulumi.get(self, "ext_domain_package")

    @property
    @pulumi.getter(name="logStorage")
    def log_storage(self) -> pulumi.Output[str]:
        """
        Log storage size. Unit: T. Valid values: [3, 5, 10, 20, 50].
        """
        return pulumi.get(self, "log_storage")

    @property
    @pulumi.getter(name="logTime")
    def log_time(self) -> pulumi.Output[str]:
        """
        Log storage period. Unit: day. Valid values: [180, 360].
        """
        return pulumi.get(self, "log_time")

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> pulumi.Output[Optional[str]]:
        """
        Type of configuration change. Valid value: Upgrade.
        """
        return pulumi.get(self, "modify_type")

    @property
    @pulumi.getter(name="packageCode")
    def package_code(self) -> pulumi.Output[str]:
        """
        Subscription plan:
        * China site customers can purchase the following versions of China Mainland region, valid values: ["version_3", "version_4", "version_5"].
        * China site customers can purchase the following versions of International region, valid values: ["version_pro_asia", "version_business_asia", "version_enterprise_asia"]
        * International site customers can purchase the following versions of China Mainland region: ["version_pro_china", "version_business_china", "version_enterprise_china"]
        * International site customers can purchase the following versions of International region: ["version_pro", "version_business", "version_enterprise"].
        """
        return pulumi.get(self, "package_code")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        Service time of Web Application Firewall.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="prefessionalService")
    def prefessional_service(self) -> pulumi.Output[str]:
        """
        Specify whether professional service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "prefessional_service")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[str]]:
        """
        The instance region ID.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> pulumi.Output[Optional[int]]:
        """
        Renewal period of WAF service. Unit: month
        """
        return pulumi.get(self, "renew_period")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> pulumi.Output[Optional[str]]:
        """
        Renewal status of WAF service. Valid values: 
        * AutoRenewal: The service time of WAF is renewed automatically.
        * ManualRenewal (default): The service time of WAF is renewed manually.Specifies whether to configure a Layer-7 proxy, such as Anti-DDoS Pro or CDN, to filter the inbound traffic before it is forwarded to WAF. Valid values: "On" and "Off". Default to "Off".
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The resource group ID.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[int]:
        """
        The status of the instance.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subscriptionType")
    def subscription_type(self) -> pulumi.Output[str]:
        """
        Subscription of WAF service. Valid values: ["Subscription", "PayAsYouGo"].
        """
        return pulumi.get(self, "subscription_type")

    @property
    @pulumi.getter(name="wafLog")
    def waf_log(self) -> pulumi.Output[str]:
        """
        Specify whether Log service is supported. Valid values: ["true", "false"]
        """
        return pulumi.get(self, "waf_log")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['GatewayEndpointArgs', 'GatewayEndpoint']

@pulumi.input_type
class GatewayEndpointArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[str],
                 vpc_id: pulumi.Input[str],
                 gateway_endpoint_descrption: Optional[pulumi.Input[str]] = None,
                 gateway_endpoint_name: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a GatewayEndpoint resource.
        :param pulumi.Input[str] service_name: The name of endpoint service.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] gateway_endpoint_descrption: The description of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_name: The name of the gateway endpoint.
        :param pulumi.Input[str] policy_document: Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the instance belongs.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of the resource.
        """
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if gateway_endpoint_descrption is not None:
            pulumi.set(__self__, "gateway_endpoint_descrption", gateway_endpoint_descrption)
        if gateway_endpoint_name is not None:
            pulumi.set(__self__, "gateway_endpoint_name", gateway_endpoint_name)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[str]:
        """
        The name of endpoint service.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="gatewayEndpointDescrption")
    def gateway_endpoint_descrption(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_descrption")

    @gateway_endpoint_descrption.setter
    def gateway_endpoint_descrption(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_endpoint_descrption", value)

    @property
    @pulumi.getter(name="gatewayEndpointName")
    def gateway_endpoint_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_name")

    @gateway_endpoint_name.setter
    def gateway_endpoint_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_endpoint_name", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group to which the instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _GatewayEndpointState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 gateway_endpoint_descrption: Optional[pulumi.Input[str]] = None,
                 gateway_endpoint_name: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GatewayEndpoint resources.
        :param pulumi.Input[str] create_time: The creation time of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_descrption: The description of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_name: The name of the gateway endpoint.
        :param pulumi.Input[str] policy_document: Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the instance belongs.
        :param pulumi.Input[str] service_name: The name of endpoint service.
        :param pulumi.Input[str] status: The status of VPC gateway endpoint.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if gateway_endpoint_descrption is not None:
            pulumi.set(__self__, "gateway_endpoint_descrption", gateway_endpoint_descrption)
        if gateway_endpoint_name is not None:
            pulumi.set(__self__, "gateway_endpoint_name", gateway_endpoint_name)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the gateway endpoint.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="gatewayEndpointDescrption")
    def gateway_endpoint_descrption(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_descrption")

    @gateway_endpoint_descrption.setter
    def gateway_endpoint_descrption(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_endpoint_descrption", value)

    @property
    @pulumi.getter(name="gatewayEndpointName")
    def gateway_endpoint_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_name")

    @gateway_endpoint_name.setter
    def gateway_endpoint_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gateway_endpoint_name", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group to which the instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of endpoint service.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of VPC gateway endpoint.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)


class GatewayEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_endpoint_descrption: Optional[pulumi.Input[str]] = None,
                 gateway_endpoint_name: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a VPC Gateway Endpoint resource. VPC gateway endpoint.

        For information about VPC Gateway Endpoint and how to use it, see [What is Gateway Endpoint](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/gateway-endpoint).

        > **NOTE:** Available since v1.208.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        domain = config.get("domain")
        if domain is None:
            domain = "com.aliyun.cn-hangzhou.oss"
        default_vpc = alicloud.vpc.Network("defaultVpc", description="tf-example")
        default_rg = alicloud.resourcemanager.ResourceGroup("defaultRg",
            display_name="tf-example-497",
            resource_group_name=name)
        default = alicloud.vpc.GatewayEndpoint("default",
            gateway_endpoint_descrption="test-gateway-endpoint",
            gateway_endpoint_name=name,
            vpc_id=default_vpc.id,
            resource_group_id=default_rg.id,
            service_name=domain,
            policy_document="{ \\"Version\\" : \\"1\\", \\"Statement\\" : [ { \\"Effect\\" : \\"Allow\\", \\"Resource\\" : [ \\"*\\" ], \\"Action\\" : [ \\"*\\" ], \\"Principal\\" : [ \\"*\\" ] } ] }")
        ```

        ## Import

        VPC Gateway Endpoint can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/gatewayEndpoint:GatewayEndpoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] gateway_endpoint_descrption: The description of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_name: The name of the gateway endpoint.
        :param pulumi.Input[str] policy_document: Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the instance belongs.
        :param pulumi.Input[str] service_name: The name of endpoint service.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a VPC Gateway Endpoint resource. VPC gateway endpoint.

        For information about VPC Gateway Endpoint and how to use it, see [What is Gateway Endpoint](https://www.alibabacloud.com/help/en/virtual-private-cloud/latest/gateway-endpoint).

        > **NOTE:** Available since v1.208.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        domain = config.get("domain")
        if domain is None:
            domain = "com.aliyun.cn-hangzhou.oss"
        default_vpc = alicloud.vpc.Network("defaultVpc", description="tf-example")
        default_rg = alicloud.resourcemanager.ResourceGroup("defaultRg",
            display_name="tf-example-497",
            resource_group_name=name)
        default = alicloud.vpc.GatewayEndpoint("default",
            gateway_endpoint_descrption="test-gateway-endpoint",
            gateway_endpoint_name=name,
            vpc_id=default_vpc.id,
            resource_group_id=default_rg.id,
            service_name=domain,
            policy_document="{ \\"Version\\" : \\"1\\", \\"Statement\\" : [ { \\"Effect\\" : \\"Allow\\", \\"Resource\\" : [ \\"*\\" ], \\"Action\\" : [ \\"*\\" ], \\"Principal\\" : [ \\"*\\" ] } ] }")
        ```

        ## Import

        VPC Gateway Endpoint can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/gatewayEndpoint:GatewayEndpoint example <id>
        ```

        :param str resource_name: The name of the resource.
        :param GatewayEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 gateway_endpoint_descrption: Optional[pulumi.Input[str]] = None,
                 gateway_endpoint_name: Optional[pulumi.Input[str]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 service_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayEndpointArgs.__new__(GatewayEndpointArgs)

            __props__.__dict__["gateway_endpoint_descrption"] = gateway_endpoint_descrption
            __props__.__dict__["gateway_endpoint_name"] = gateway_endpoint_name
            __props__.__dict__["policy_document"] = policy_document
            __props__.__dict__["resource_group_id"] = resource_group_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(GatewayEndpoint, __self__).__init__(
            'alicloud:vpc/gatewayEndpoint:GatewayEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            gateway_endpoint_descrption: Optional[pulumi.Input[str]] = None,
            gateway_endpoint_name: Optional[pulumi.Input[str]] = None,
            policy_document: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            service_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            vpc_id: Optional[pulumi.Input[str]] = None) -> 'GatewayEndpoint':
        """
        Get an existing GatewayEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_descrption: The description of the gateway endpoint.
        :param pulumi.Input[str] gateway_endpoint_name: The name of the gateway endpoint.
        :param pulumi.Input[str] policy_document: Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        :param pulumi.Input[str] resource_group_id: The ID of the resource group to which the instance belongs.
        :param pulumi.Input[str] service_name: The name of endpoint service.
        :param pulumi.Input[str] status: The status of VPC gateway endpoint.
        :param pulumi.Input[Mapping[str, Any]] tags: The tags of the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayEndpointState.__new__(_GatewayEndpointState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["gateway_endpoint_descrption"] = gateway_endpoint_descrption
        __props__.__dict__["gateway_endpoint_name"] = gateway_endpoint_name
        __props__.__dict__["policy_document"] = policy_document
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_id"] = vpc_id
        return GatewayEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the gateway endpoint.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="gatewayEndpointDescrption")
    def gateway_endpoint_descrption(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_descrption")

    @property
    @pulumi.getter(name="gatewayEndpointName")
    def gateway_endpoint_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the gateway endpoint.
        """
        return pulumi.get(self, "gateway_endpoint_name")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> pulumi.Output[Optional[str]]:
        """
        Access control policies for cloud services. This parameter is required when the cloud service is oss. For details about the syntax and structure of access policies, see [syntax and structure of permission Policies](https://help.aliyun.com/document_detail/93739.html).
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The ID of the resource group to which the instance belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[str]:
        """
        The name of endpoint service.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of VPC gateway endpoint.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        The tags of the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetBasicEndpointsResult',
    'AwaitableGetBasicEndpointsResult',
    'get_basic_endpoints',
    'get_basic_endpoints_output',
]

@pulumi.output_type
class GetBasicEndpointsResult:
    """
    A collection of values returned by getBasicEndpoints.
    """
    def __init__(__self__, endpoint_group_id=None, endpoint_id=None, endpoint_type=None, endpoints=None, id=None, ids=None, name=None, name_regex=None, names=None, output_file=None, status=None):
        if endpoint_group_id and not isinstance(endpoint_group_id, str):
            raise TypeError("Expected argument 'endpoint_group_id' to be a str")
        pulumi.set(__self__, "endpoint_group_id", endpoint_group_id)
        if endpoint_id and not isinstance(endpoint_id, str):
            raise TypeError("Expected argument 'endpoint_id' to be a str")
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_type and not isinstance(endpoint_type, str):
            raise TypeError("Expected argument 'endpoint_type' to be a str")
        pulumi.set(__self__, "endpoint_type", endpoint_type)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="endpointGroupId")
    def endpoint_group_id(self) -> str:
        """
        The ID of the Basic Endpoint Group.
        """
        return pulumi.get(self, "endpoint_group_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[str]:
        """
        The ID of the Basic Endpoint.
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[str]:
        """
        The type of the Basic Endpoint.
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetBasicEndpointsEndpointResult']:
        """
        A list of Global Accelerator Basic Endpoints. Each element contains the following attributes:
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Global Accelerator Basic Endpoint names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the Basic Endpoint.
        """
        return pulumi.get(self, "status")


class AwaitableGetBasicEndpointsResult(GetBasicEndpointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBasicEndpointsResult(
            endpoint_group_id=self.endpoint_group_id,
            endpoint_id=self.endpoint_id,
            endpoint_type=self.endpoint_type,
            endpoints=self.endpoints,
            id=self.id,
            ids=self.ids,
            name=self.name,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status)


def get_basic_endpoints(endpoint_group_id: Optional[str] = None,
                        endpoint_id: Optional[str] = None,
                        endpoint_type: Optional[str] = None,
                        ids: Optional[Sequence[str]] = None,
                        name: Optional[str] = None,
                        name_regex: Optional[str] = None,
                        output_file: Optional[str] = None,
                        status: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBasicEndpointsResult:
    """
    This data source provides the Global Accelerator (GA) Basic Endpoints of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_endpoints(ids=["example_id"],
        endpoint_group_id="example_id")
    pulumi.export("gaBasicEndpointsId1", ids.endpoints[0].id)
    name_regex = alicloud.ga.get_basic_endpoints(name_regex="tf-example",
        endpoint_group_id="example_id")
    pulumi.export("gaBasicEndpointsId2", name_regex.endpoints[0].id)
    ```


    :param str endpoint_group_id: The ID of the Basic Endpoint Group.
    :param str endpoint_id: The ID of the Basic Endpoint.
    :param str endpoint_type: The type of the Basic Endpoint. Valid values: `ENI`, `SLB`, `ECS` and `NLB`.
    :param Sequence[str] ids: A list of Global Accelerator Basic Endpoints IDs.
    :param str name: The name of the Basic Endpoint.
    :param str name_regex: A regex string to filter results by Global Accelerator Basic Endpoints name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Accelerator Basic Endpoint. Valid Value: `init`, `active`, `updating`, `binding`, `unbinding`, `deleting`, `bound`.
    """
    __args__ = dict()
    __args__['endpointGroupId'] = endpoint_group_id
    __args__['endpointId'] = endpoint_id
    __args__['endpointType'] = endpoint_type
    __args__['ids'] = ids
    __args__['name'] = name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getBasicEndpoints:getBasicEndpoints', __args__, opts=opts, typ=GetBasicEndpointsResult).value

    return AwaitableGetBasicEndpointsResult(
        endpoint_group_id=pulumi.get(__ret__, 'endpoint_group_id'),
        endpoint_id=pulumi.get(__ret__, 'endpoint_id'),
        endpoint_type=pulumi.get(__ret__, 'endpoint_type'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name=pulumi.get(__ret__, 'name'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))


@_utilities.lift_output_func(get_basic_endpoints)
def get_basic_endpoints_output(endpoint_group_id: Optional[pulumi.Input[str]] = None,
                               endpoint_id: Optional[pulumi.Input[Optional[str]]] = None,
                               endpoint_type: Optional[pulumi.Input[Optional[str]]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               name: Optional[pulumi.Input[Optional[str]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBasicEndpointsResult]:
    """
    This data source provides the Global Accelerator (GA) Basic Endpoints of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_endpoints(ids=["example_id"],
        endpoint_group_id="example_id")
    pulumi.export("gaBasicEndpointsId1", ids.endpoints[0].id)
    name_regex = alicloud.ga.get_basic_endpoints(name_regex="tf-example",
        endpoint_group_id="example_id")
    pulumi.export("gaBasicEndpointsId2", name_regex.endpoints[0].id)
    ```


    :param str endpoint_group_id: The ID of the Basic Endpoint Group.
    :param str endpoint_id: The ID of the Basic Endpoint.
    :param str endpoint_type: The type of the Basic Endpoint. Valid values: `ENI`, `SLB`, `ECS` and `NLB`.
    :param Sequence[str] ids: A list of Global Accelerator Basic Endpoints IDs.
    :param str name: The name of the Basic Endpoint.
    :param str name_regex: A regex string to filter results by Global Accelerator Basic Endpoints name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the Global Accelerator Basic Endpoint. Valid Value: `init`, `active`, `updating`, `binding`, `unbinding`, `deleting`, `bound`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 applications: pulumi.Input[Sequence[pulumi.Input[str]]],
                 cluster_name: pulumi.Input[str],
                 cluster_type: pulumi.Input[str],
                 node_attributes: pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]],
                 node_groups: pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]],
                 release_version: pulumi.Input[str],
                 application_configs: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]] = None,
                 bootstrap_scripts: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]] = None,
                 deploy_mode: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_mode: Optional[pulumi.Input[str]] = None,
                 subscription_config: Optional[pulumi.Input['ClusterSubscriptionConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] applications: The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        :param pulumi.Input[str] cluster_name: The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        :param pulumi.Input[str] cluster_type: EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]] node_attributes: The node attributes of ecs instances which the emr-cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]] node_groups: Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        :param pulumi.Input[str] release_version: EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]] application_configs: The application configurations of EMR cluster.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]] bootstrap_scripts: The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        :param pulumi.Input[str] deploy_mode: The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        :param pulumi.Input[str] payment_type: Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        :param pulumi.Input[str] resource_group_id: The Id of resource group which the emr-cluster belongs.
        :param pulumi.Input[str] security_mode: The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        :param pulumi.Input['ClusterSubscriptionConfigArgs'] subscription_config: The detail configuration of subscription payment type.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "applications", applications)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "node_attributes", node_attributes)
        pulumi.set(__self__, "node_groups", node_groups)
        pulumi.set(__self__, "release_version", release_version)
        if application_configs is not None:
            pulumi.set(__self__, "application_configs", application_configs)
        if bootstrap_scripts is not None:
            pulumi.set(__self__, "bootstrap_scripts", bootstrap_scripts)
        if deploy_mode is not None:
            pulumi.set(__self__, "deploy_mode", deploy_mode)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if security_mode is not None:
            pulumi.set(__self__, "security_mode", security_mode)
        if subscription_config is not None:
            pulumi.set(__self__, "subscription_config", subscription_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def applications(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        """
        return pulumi.get(self, "applications")

    @applications.setter
    def applications(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "applications", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Input[str]:
        """
        The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Input[str]:
        """
        EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter(name="nodeAttributes")
    def node_attributes(self) -> pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]]:
        """
        The node attributes of ecs instances which the emr-cluster belongs.
        """
        return pulumi.get(self, "node_attributes")

    @node_attributes.setter
    def node_attributes(self, value: pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]]):
        pulumi.set(self, "node_attributes", value)

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]:
        """
        Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        """
        return pulumi.get(self, "node_groups")

    @node_groups.setter
    def node_groups(self, value: pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]):
        pulumi.set(self, "node_groups", value)

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> pulumi.Input[str]:
        """
        EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        """
        return pulumi.get(self, "release_version")

    @release_version.setter
    def release_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "release_version", value)

    @property
    @pulumi.getter(name="applicationConfigs")
    def application_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]]:
        """
        The application configurations of EMR cluster.
        """
        return pulumi.get(self, "application_configs")

    @application_configs.setter
    def application_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]]):
        pulumi.set(self, "application_configs", value)

    @property
    @pulumi.getter(name="bootstrapScripts")
    def bootstrap_scripts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]]:
        """
        The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        """
        return pulumi.get(self, "bootstrap_scripts")

    @bootstrap_scripts.setter
    def bootstrap_scripts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]]):
        pulumi.set(self, "bootstrap_scripts", value)

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        """
        return pulumi.get(self, "deploy_mode")

    @deploy_mode.setter
    def deploy_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deploy_mode", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Id of resource group which the emr-cluster belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="securityMode")
    def security_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        """
        return pulumi.get(self, "security_mode")

    @security_mode.setter
    def security_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_mode", value)

    @property
    @pulumi.getter(name="subscriptionConfig")
    def subscription_config(self) -> Optional[pulumi.Input['ClusterSubscriptionConfigArgs']]:
        """
        The detail configuration of subscription payment type.
        """
        return pulumi.get(self, "subscription_config")

    @subscription_config.setter
    def subscription_config(self, value: Optional[pulumi.Input['ClusterSubscriptionConfigArgs']]):
        pulumi.set(self, "subscription_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 application_configs: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bootstrap_scripts: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 deploy_mode: Optional[pulumi.Input[str]] = None,
                 node_attributes: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_mode: Optional[pulumi.Input[str]] = None,
                 subscription_config: Optional[pulumi.Input['ClusterSubscriptionConfigArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]] application_configs: The application configurations of EMR cluster.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] applications: The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]] bootstrap_scripts: The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        :param pulumi.Input[str] cluster_name: The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        :param pulumi.Input[str] cluster_type: EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        :param pulumi.Input[str] deploy_mode: The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]] node_attributes: The node attributes of ecs instances which the emr-cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]] node_groups: Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        :param pulumi.Input[str] payment_type: Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        :param pulumi.Input[str] release_version: EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        :param pulumi.Input[str] resource_group_id: The Id of resource group which the emr-cluster belongs.
        :param pulumi.Input[str] security_mode: The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        :param pulumi.Input['ClusterSubscriptionConfigArgs'] subscription_config: The detail configuration of subscription payment type.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        """
        if application_configs is not None:
            pulumi.set(__self__, "application_configs", application_configs)
        if applications is not None:
            pulumi.set(__self__, "applications", applications)
        if bootstrap_scripts is not None:
            pulumi.set(__self__, "bootstrap_scripts", bootstrap_scripts)
        if cluster_name is not None:
            pulumi.set(__self__, "cluster_name", cluster_name)
        if cluster_type is not None:
            pulumi.set(__self__, "cluster_type", cluster_type)
        if deploy_mode is not None:
            pulumi.set(__self__, "deploy_mode", deploy_mode)
        if node_attributes is not None:
            pulumi.set(__self__, "node_attributes", node_attributes)
        if node_groups is not None:
            pulumi.set(__self__, "node_groups", node_groups)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if release_version is not None:
            pulumi.set(__self__, "release_version", release_version)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if security_mode is not None:
            pulumi.set(__self__, "security_mode", security_mode)
        if subscription_config is not None:
            pulumi.set(__self__, "subscription_config", subscription_config)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="applicationConfigs")
    def application_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]]:
        """
        The application configurations of EMR cluster.
        """
        return pulumi.get(self, "application_configs")

    @application_configs.setter
    def application_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterApplicationConfigArgs']]]]):
        pulumi.set(self, "application_configs", value)

    @property
    @pulumi.getter
    def applications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        """
        return pulumi.get(self, "applications")

    @applications.setter
    def applications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "applications", value)

    @property
    @pulumi.getter(name="bootstrapScripts")
    def bootstrap_scripts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]]:
        """
        The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        """
        return pulumi.get(self, "bootstrap_scripts")

    @bootstrap_scripts.setter
    def bootstrap_scripts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterBootstrapScriptArgs']]]]):
        pulumi.set(self, "bootstrap_scripts", value)

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        """
        return pulumi.get(self, "cluster_name")

    @cluster_name.setter
    def cluster_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_name", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> Optional[pulumi.Input[str]]:
        """
        EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        """
        return pulumi.get(self, "deploy_mode")

    @deploy_mode.setter
    def deploy_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deploy_mode", value)

    @property
    @pulumi.getter(name="nodeAttributes")
    def node_attributes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]]]:
        """
        The node attributes of ecs instances which the emr-cluster belongs.
        """
        return pulumi.get(self, "node_attributes")

    @node_attributes.setter
    def node_attributes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeAttributeArgs']]]]):
        pulumi.set(self, "node_attributes", value)

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]:
        """
        Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        """
        return pulumi.get(self, "node_groups")

    @node_groups.setter
    def node_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ClusterNodeGroupArgs']]]]):
        pulumi.set(self, "node_groups", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> Optional[pulumi.Input[str]]:
        """
        EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        """
        return pulumi.get(self, "release_version")

    @release_version.setter
    def release_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "release_version", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Id of resource group which the emr-cluster belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="securityMode")
    def security_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        """
        return pulumi.get(self, "security_mode")

    @security_mode.setter
    def security_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_mode", value)

    @property
    @pulumi.getter(name="subscriptionConfig")
    def subscription_config(self) -> Optional[pulumi.Input['ClusterSubscriptionConfigArgs']]:
        """
        The detail configuration of subscription payment type.
        """
        return pulumi.get(self, "subscription_config")

    @subscription_config.setter
    def subscription_config(self, value: Optional[pulumi.Input['ClusterSubscriptionConfigArgs']]):
        pulumi.set(self, "subscription_config", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_configs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationConfigArgs']]]]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bootstrap_scripts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapScriptArgs']]]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 deploy_mode: Optional[pulumi.Input[str]] = None,
                 node_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeAttributeArgs']]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeGroupArgs']]]]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_mode: Optional[pulumi.Input[str]] = None,
                 subscription_config: Optional[pulumi.Input[pulumi.InputType['ClusterSubscriptionConfigArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        Provides a EMR cluster resource. This resource is based on EMR's new version OpenAPI.

        For information about EMR New and how to use it, see [Add a domain](https://www.alibabacloud.com/help/doc-detail/28068.htm).

        > **NOTE:** Available in v1.199.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_zones = alicloud.get_zones(available_instance_type="ecs.g7.xlarge")
        default_network = alicloud.vpc.Network("defaultNetwork",
            vpc_name="TF-VPC",
            cidr_block="172.16.0.0/12")
        default_switch = alicloud.vpc.Switch("defaultSwitch",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/21",
            zone_id=default_zones.zones[0].id,
            vswitch_name="TF_VSwitch")
        default_ecs_key_pair = alicloud.ecs.EcsKeyPair("defaultEcsKeyPair", key_pair_name="terraform-kp")
        default_security_group = alicloud.ecs.SecurityGroup("defaultSecurityGroup", vpc_id=default_network.id)
        default_role = alicloud.ram.Role("defaultRole",
            document=\"\"\"    {
                "Statement": [
                {
                    "Action": "sts:AssumeRole",
                    "Effect": "Allow",
                    "Principal": {
                    "Service": [
                        "emr.aliyuncs.com",
                        "ecs.aliyuncs.com"
                    ]
                    }
                }
                ],
                "Version": "1"
            }
        \"\"\",
            description="this is a role test.",
            force=True)
        default_cluster = alicloud.emrv2.Cluster("defaultCluster",
            payment_type="PayAsYouGo",
            cluster_type="DATALAKE",
            release_version="EMR-5.10.0",
            cluster_name="terraform-emr-cluster-v2",
            deploy_mode="NORMAL",
            security_mode="NORMAL",
            applications=[
                "HADOOP-COMMON",
                "HDFS",
                "YARN",
                "HIVE",
                "SPARK3",
                "TEZ",
            ],
            application_configs=[
                alicloud.emrv2.ClusterApplicationConfigArgs(
                    application_name="HIVE",
                    config_file_name="hivemetastore-site.xml",
                    config_item_key="hive.metastore.type",
                    config_item_value="DLF",
                    config_scope="CLUSTER",
                ),
                alicloud.emrv2.ClusterApplicationConfigArgs(
                    application_name="SPARK3",
                    config_file_name="hive-site.xml",
                    config_item_key="hive.metastore.type",
                    config_item_value="DLF",
                    config_scope="CLUSTER",
                ),
            ],
            node_attributes=[alicloud.emrv2.ClusterNodeAttributeArgs(
                ram_role=default_role.name,
                security_group_id=default_security_group.id,
                vpc_id=default_network.id,
                zone_id=default_zones.zones[0].id,
                key_pair_name=default_ecs_key_pair.id,
            )],
            tags={
                "created": "tf",
            },
            node_groups=[
                alicloud.emrv2.ClusterNodeGroupArgs(
                    node_group_type="MASTER",
                    node_group_name="emr-master",
                    payment_type="PayAsYouGo",
                    vswitch_ids=[default_switch.id],
                    with_public_ip=False,
                    instance_types=["ecs.g7.xlarge"],
                    node_count=1,
                    system_disk=alicloud.emrv2.ClusterNodeGroupSystemDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=1,
                    ),
                    data_disks=[alicloud.emrv2.ClusterNodeGroupDataDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=3,
                    )],
                ),
                alicloud.emrv2.ClusterNodeGroupArgs(
                    node_group_type="CORE",
                    node_group_name="emr-core",
                    payment_type="PayAsYouGo",
                    vswitch_ids=[default_switch.id],
                    with_public_ip=False,
                    instance_types=["ecs.g7.xlarge"],
                    node_count=3,
                    system_disk=alicloud.emrv2.ClusterNodeGroupSystemDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=1,
                    ),
                    data_disks=[alicloud.emrv2.ClusterNodeGroupDataDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=3,
                    )],
                ),
            ],
            resource_group_id=default_resource_groups.ids[0])
        ```

        ## Import

        Aliclioud E-MapReduce cluster can be imported using the id e.g.

        ```sh
         $ pulumi import alicloud:emrv2/cluster:Cluster default <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationConfigArgs']]]] application_configs: The application configurations of EMR cluster.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] applications: The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapScriptArgs']]]] bootstrap_scripts: The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        :param pulumi.Input[str] cluster_name: The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        :param pulumi.Input[str] cluster_type: EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        :param pulumi.Input[str] deploy_mode: The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeAttributeArgs']]]] node_attributes: The node attributes of ecs instances which the emr-cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeGroupArgs']]]] node_groups: Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        :param pulumi.Input[str] payment_type: Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        :param pulumi.Input[str] release_version: EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        :param pulumi.Input[str] resource_group_id: The Id of resource group which the emr-cluster belongs.
        :param pulumi.Input[str] security_mode: The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        :param pulumi.Input[pulumi.InputType['ClusterSubscriptionConfigArgs']] subscription_config: The detail configuration of subscription payment type.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a EMR cluster resource. This resource is based on EMR's new version OpenAPI.

        For information about EMR New and how to use it, see [Add a domain](https://www.alibabacloud.com/help/doc-detail/28068.htm).

        > **NOTE:** Available in v1.199.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups(status="OK")
        default_zones = alicloud.get_zones(available_instance_type="ecs.g7.xlarge")
        default_network = alicloud.vpc.Network("defaultNetwork",
            vpc_name="TF-VPC",
            cidr_block="172.16.0.0/12")
        default_switch = alicloud.vpc.Switch("defaultSwitch",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/21",
            zone_id=default_zones.zones[0].id,
            vswitch_name="TF_VSwitch")
        default_ecs_key_pair = alicloud.ecs.EcsKeyPair("defaultEcsKeyPair", key_pair_name="terraform-kp")
        default_security_group = alicloud.ecs.SecurityGroup("defaultSecurityGroup", vpc_id=default_network.id)
        default_role = alicloud.ram.Role("defaultRole",
            document=\"\"\"    {
                "Statement": [
                {
                    "Action": "sts:AssumeRole",
                    "Effect": "Allow",
                    "Principal": {
                    "Service": [
                        "emr.aliyuncs.com",
                        "ecs.aliyuncs.com"
                    ]
                    }
                }
                ],
                "Version": "1"
            }
        \"\"\",
            description="this is a role test.",
            force=True)
        default_cluster = alicloud.emrv2.Cluster("defaultCluster",
            payment_type="PayAsYouGo",
            cluster_type="DATALAKE",
            release_version="EMR-5.10.0",
            cluster_name="terraform-emr-cluster-v2",
            deploy_mode="NORMAL",
            security_mode="NORMAL",
            applications=[
                "HADOOP-COMMON",
                "HDFS",
                "YARN",
                "HIVE",
                "SPARK3",
                "TEZ",
            ],
            application_configs=[
                alicloud.emrv2.ClusterApplicationConfigArgs(
                    application_name="HIVE",
                    config_file_name="hivemetastore-site.xml",
                    config_item_key="hive.metastore.type",
                    config_item_value="DLF",
                    config_scope="CLUSTER",
                ),
                alicloud.emrv2.ClusterApplicationConfigArgs(
                    application_name="SPARK3",
                    config_file_name="hive-site.xml",
                    config_item_key="hive.metastore.type",
                    config_item_value="DLF",
                    config_scope="CLUSTER",
                ),
            ],
            node_attributes=[alicloud.emrv2.ClusterNodeAttributeArgs(
                ram_role=default_role.name,
                security_group_id=default_security_group.id,
                vpc_id=default_network.id,
                zone_id=default_zones.zones[0].id,
                key_pair_name=default_ecs_key_pair.id,
            )],
            tags={
                "created": "tf",
            },
            node_groups=[
                alicloud.emrv2.ClusterNodeGroupArgs(
                    node_group_type="MASTER",
                    node_group_name="emr-master",
                    payment_type="PayAsYouGo",
                    vswitch_ids=[default_switch.id],
                    with_public_ip=False,
                    instance_types=["ecs.g7.xlarge"],
                    node_count=1,
                    system_disk=alicloud.emrv2.ClusterNodeGroupSystemDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=1,
                    ),
                    data_disks=[alicloud.emrv2.ClusterNodeGroupDataDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=3,
                    )],
                ),
                alicloud.emrv2.ClusterNodeGroupArgs(
                    node_group_type="CORE",
                    node_group_name="emr-core",
                    payment_type="PayAsYouGo",
                    vswitch_ids=[default_switch.id],
                    with_public_ip=False,
                    instance_types=["ecs.g7.xlarge"],
                    node_count=3,
                    system_disk=alicloud.emrv2.ClusterNodeGroupSystemDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=1,
                    ),
                    data_disks=[alicloud.emrv2.ClusterNodeGroupDataDiskArgs(
                        category="cloud_essd",
                        size=80,
                        count=3,
                    )],
                ),
            ],
            resource_group_id=default_resource_groups.ids[0])
        ```

        ## Import

        Aliclioud E-MapReduce cluster can be imported using the id e.g.

        ```sh
         $ pulumi import alicloud:emrv2/cluster:Cluster default <id>
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_configs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationConfigArgs']]]]] = None,
                 applications: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bootstrap_scripts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapScriptArgs']]]]] = None,
                 cluster_name: Optional[pulumi.Input[str]] = None,
                 cluster_type: Optional[pulumi.Input[str]] = None,
                 deploy_mode: Optional[pulumi.Input[str]] = None,
                 node_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeAttributeArgs']]]]] = None,
                 node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeGroupArgs']]]]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 release_version: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 security_mode: Optional[pulumi.Input[str]] = None,
                 subscription_config: Optional[pulumi.Input[pulumi.InputType['ClusterSubscriptionConfigArgs']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["application_configs"] = application_configs
            if applications is None and not opts.urn:
                raise TypeError("Missing required property 'applications'")
            __props__.__dict__["applications"] = applications
            __props__.__dict__["bootstrap_scripts"] = bootstrap_scripts
            if cluster_name is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_name'")
            __props__.__dict__["cluster_name"] = cluster_name
            if cluster_type is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_type'")
            __props__.__dict__["cluster_type"] = cluster_type
            __props__.__dict__["deploy_mode"] = deploy_mode
            if node_attributes is None and not opts.urn:
                raise TypeError("Missing required property 'node_attributes'")
            __props__.__dict__["node_attributes"] = node_attributes
            if node_groups is None and not opts.urn:
                raise TypeError("Missing required property 'node_groups'")
            __props__.__dict__["node_groups"] = node_groups
            __props__.__dict__["payment_type"] = payment_type
            if release_version is None and not opts.urn:
                raise TypeError("Missing required property 'release_version'")
            __props__.__dict__["release_version"] = release_version
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["security_mode"] = security_mode
            __props__.__dict__["subscription_config"] = subscription_config
            __props__.__dict__["tags"] = tags
        super(Cluster, __self__).__init__(
            'alicloud:emrv2/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_configs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationConfigArgs']]]]] = None,
            applications: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            bootstrap_scripts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapScriptArgs']]]]] = None,
            cluster_name: Optional[pulumi.Input[str]] = None,
            cluster_type: Optional[pulumi.Input[str]] = None,
            deploy_mode: Optional[pulumi.Input[str]] = None,
            node_attributes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeAttributeArgs']]]]] = None,
            node_groups: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeGroupArgs']]]]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            release_version: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            security_mode: Optional[pulumi.Input[str]] = None,
            subscription_config: Optional[pulumi.Input[pulumi.InputType['ClusterSubscriptionConfigArgs']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterApplicationConfigArgs']]]] application_configs: The application configurations of EMR cluster.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] applications: The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterBootstrapScriptArgs']]]] bootstrap_scripts: The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        :param pulumi.Input[str] cluster_name: The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        :param pulumi.Input[str] cluster_type: EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        :param pulumi.Input[str] deploy_mode: The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeAttributeArgs']]]] node_attributes: The node attributes of ecs instances which the emr-cluster belongs.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ClusterNodeGroupArgs']]]] node_groups: Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        :param pulumi.Input[str] payment_type: Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        :param pulumi.Input[str] release_version: EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        :param pulumi.Input[str] resource_group_id: The Id of resource group which the emr-cluster belongs.
        :param pulumi.Input[str] security_mode: The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        :param pulumi.Input[pulumi.InputType['ClusterSubscriptionConfigArgs']] subscription_config: The detail configuration of subscription payment type.
        :param pulumi.Input[Mapping[str, Any]] tags: A mapping of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["application_configs"] = application_configs
        __props__.__dict__["applications"] = applications
        __props__.__dict__["bootstrap_scripts"] = bootstrap_scripts
        __props__.__dict__["cluster_name"] = cluster_name
        __props__.__dict__["cluster_type"] = cluster_type
        __props__.__dict__["deploy_mode"] = deploy_mode
        __props__.__dict__["node_attributes"] = node_attributes
        __props__.__dict__["node_groups"] = node_groups
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["release_version"] = release_version
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["security_mode"] = security_mode
        __props__.__dict__["subscription_config"] = subscription_config
        __props__.__dict__["tags"] = tags
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationConfigs")
    def application_configs(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterApplicationConfig']]]:
        """
        The application configurations of EMR cluster.
        """
        return pulumi.get(self, "application_configs")

    @property
    @pulumi.getter
    def applications(self) -> pulumi.Output[Sequence[str]]:
        """
        The applications of EMR cluster to be installed, e.g. HADOOP-COMMON, HDFS, YARN, HIVE, SPARK2, SPARK3, ZOOKEEPER etc. You can find all valid applications in emr web console.
        """
        return pulumi.get(self, "applications")

    @property
    @pulumi.getter(name="bootstrapScripts")
    def bootstrap_scripts(self) -> pulumi.Output[Optional[Sequence['outputs.ClusterBootstrapScript']]]:
        """
        The bootstrap scripts to be effected when creating emr-cluster or resize emr-cluster.
        """
        return pulumi.get(self, "bootstrap_scripts")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> pulumi.Output[str]:
        """
        The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Output[str]:
        """
        EMR Cluster Type, e.g. DATALAKE, OLAP, DATAFLOW, DATASERVING, CUSTOM etc. You can find all valid EMR cluster type in emr web console.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter(name="deployMode")
    def deploy_mode(self) -> pulumi.Output[str]:
        """
        The deploy mode of EMR cluster. Supported value: NORMAL or HA.
        """
        return pulumi.get(self, "deploy_mode")

    @property
    @pulumi.getter(name="nodeAttributes")
    def node_attributes(self) -> pulumi.Output[Sequence['outputs.ClusterNodeAttribute']]:
        """
        The node attributes of ecs instances which the emr-cluster belongs.
        """
        return pulumi.get(self, "node_attributes")

    @property
    @pulumi.getter(name="nodeGroups")
    def node_groups(self) -> pulumi.Output[Sequence['outputs.ClusterNodeGroup']]:
        """
        Groups of node, You can specify MASTER as a group, CORE as a group (just like the above example).
        """
        return pulumi.get(self, "node_groups")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        Payment Type for this cluster. Supported value: PayAsYouGo or Subscription.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> pulumi.Output[str]:
        """
        EMR Version, e.g. EMR-5.10.0. You can find the all valid EMR Version in emr web console.
        """
        return pulumi.get(self, "release_version")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The Id of resource group which the emr-cluster belongs.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="securityMode")
    def security_mode(self) -> pulumi.Output[str]:
        """
        The security mode of EMR cluster. Supported value: NORMAL or KERBEROS.
        """
        return pulumi.get(self, "security_mode")

    @property
    @pulumi.getter(name="subscriptionConfig")
    def subscription_config(self) -> pulumi.Output[Optional['outputs.ClusterSubscriptionConfig']]:
        """
        The detail configuration of subscription payment type.
        """
        return pulumi.get(self, "subscription_config")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

